
# Slot: obsolete



URI: [gocam:object__obsolete](https://w3id.org/gocam/object__obsolete)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [BiologicalProcessTermObject](BiologicalProcessTermObject.md)
 * [CellTypeTermObject](CellTypeTermObject.md)
 * [CellularAnatomicalEntityTermObject](CellularAnatomicalEntityTermObject.md)
 * [EvidenceTermObject](EvidenceTermObject.md)
 * [GeneProductTermObject](GeneProductTermObject.md)
 * [GrossAnatomicalStructureTermObject](GrossAnatomicalStructureTermObject.md)
 * [InformationBiomacromoleculeTermObject](InformationBiomacromoleculeTermObject.md)
 * [MolecularFunctionTermObject](MolecularFunctionTermObject.md)
 * [MoleculeTermObject](MoleculeTermObject.md)
 * [Object](Object.md)
 * [PhaseTermObject](PhaseTermObject.md)
 * [PredicateTermObject](PredicateTermObject.md)
 * [ProteinComplexTermObject](ProteinComplexTermObject.md)
 * [PublicationObject](PublicationObject.md)
 * [TaxonTermObject](TaxonTermObject.md)
 * [TermObject](TermObject.md)
